@@ -50,6 +50,7 @@
 #' @export
 beamer_presentation <- function(toc = FALSE,
                                 slide_level = NULL,
+                                number_sections = FALSE,
                                 incremental = FALSE,
                                 fig_width = 10,
                                 fig_height = 7,
@@ -65,7 +66,7 @@ beamer_presentation <- function(toc = FALSE,
                                 keep_tex = FALSE,
                                 keep_md = FALSE,
                                 latex_engine = "pdflatex",
-                                citation_package = c("none", "natbib", "biblatex"),
+                                citation_package = c("default", "natbib", "biblatex"),
                                 self_contained = TRUE,
                                 includes = NULL,
                                 md_extensions = NULL,
@@ -89,6 +90,9 @@ beamer_presentation <- function(toc = FALSE,
   if (!is.null(slide_level))
     args <- c(args, "--slide-level", as.character(slide_level))
 
+  if (number_sections)
+    args <- c(args, "--number-sections")
+
   # incremental
   if (incremental)
     args <- c(args, "--incremental")
@@ -107,12 +111,11 @@ beamer_presentation <- function(toc = FALSE,
   args <- c(args, pandoc_highlight_args(highlight))
 
   # latex engine
-  latex_engine = match.arg(latex_engine, c("pdflatex", "lualatex", "xelatex"))
+  latex_engine <- match.arg(latex_engine, c("pdflatex", "lualatex", "xelatex"))
   args <- c(args, pandoc_latex_engine_args(latex_engine))
 
   # citation package
-  citation_package <- match.arg(citation_package)
-  if (citation_package != "none") args <- c(args, paste0("--", citation_package))
+  args <- c(args, citation_package_arg(citation_package))
 
   # generate a self-contained LaTeX document (including preamble)
   if (self_contained) args <- c(args, "--self-contained")
