@@ -39,9 +39,6 @@
 #'  chunks by default.
 #'@param code_download Embed the Rmd source code within the document and provide
 #'  a link that can be used by readers to download the code.
-#'@param smart Produce typographically correct output, converting straight
-#'  quotes to curly quotes, \code{---} to em-dashes, \code{--} to en-dashes, and
-#'  \code{...} to ellipses.
 #'@param self_contained Produce a standalone HTML file with no external
 #'  dependencies, using data: URIs to incorporate the contents of linked
 #'  scripts, stylesheets, images, and videos. Note that even for self contained
@@ -58,9 +55,8 @@
 #'  MathJax CDN. The "local" option uses a local version of MathJax (which is
 #'  copied into the output directory). You can pass an alternate URL or pass
 #'  \code{NULL} to exclude MathJax entirely.
-#'@param section_divs Wrap sections in <div> tags (or <section> tags in HTML5),
-#'  and attach identifiers to the enclosing <div> (or <section>) rather than the
-#'  header itself.
+#'@param section_divs Wrap sections in <div> tags, and attach identifiers to the
+#'  enclosing <div> rather than the header itself.
 #'@param template Pandoc template to use for rendering. Pass "default" to use
 #'  the rmarkdown package default template; pass \code{NULL} to use pandoc's
 #'  built-in template; pass a path to use a custom template that you've created.
@@ -192,7 +188,6 @@ html_document <- function(toc = FALSE,
                           df_print = "default",
                           code_folding = c("none", "show", "hide"),
                           code_download = FALSE,
-                          smart = TRUE,
                           self_contained = TRUE,
                           theme = "default",
                           highlight = "default",
@@ -217,8 +212,6 @@ html_document <- function(toc = FALSE,
   # table of contents
   args <- c(args, pandoc_toc_args(toc, toc_depth))
 
-  md_extensions <- smart_extension(smart, md_extensions)
-
   # toc_float
   if (toc && !identical(toc_float, FALSE)) {
 
@@ -440,7 +433,7 @@ html_document <- function(toc = FALSE,
     post_knit = post_knit,
     pre_processor = pre_processor,
     on_exit = on_exit,
-    base_format = html_document_base(smart = smart, theme = theme,
+    base_format = html_document_base(theme = theme,
                                      self_contained = self_contained,
                                      lib_dir = lib_dir, mathjax = mathjax,
                                      template = template,
