@@ -23,7 +23,6 @@ html_fragment <- function(number_sections = FALSE,
                           fig_caption = TRUE,
                           dev = 'png',
                           df_print = "default",
-                          smart = TRUE,
                           mathjax = TRUE,
                           includes = NULL,
                           keep_md = FALSE,
@@ -37,7 +36,7 @@ html_fragment <- function(number_sections = FALSE,
   html_document(
     number_sections = number_sections, fig_width = fig_width,
     fig_height = fig_height, fig_retina = fig_retina, fig_caption = fig_caption,
-    dev = dev, df_print = df_print, smart = smart, keep_md = keep_md,
+    dev = dev, df_print = df_print, keep_md = keep_md,
     md_extensions = md_extensions, pandoc_args = pandoc_args, includes = includes,
     mathjax = NULL, section_divs = section_divs, highlight = NULL, theme = NULL, ...,
     template = pkg_file("rmd/fragment/default.html")
