@@ -245,8 +245,7 @@ params_namedList <- function() {
 #' @param params A named list of optional parameter overrides used in place of the document defaults.
 #' @param shiny_args Additional arguments to \code{\link[shiny:runApp]{runApp}}.
 #' @param save_caption Caption to use use for button that saves/confirms parameters.
-#' @param encoding The encoding of the input file; see \code{\link{file}}.
-#'
+#' @inheritParams render
 #' @return named list with overridden parameter names and value.
 #'
 #' @export
@@ -261,7 +260,7 @@ knit_params_ask <- function(file = NULL,
     if (is.null(file)) {
       stop("knit_params_ask must have a non-NULL file or input_lines parameter")
     }
-    input_lines <- read_utf8(file, encoding)
+    input_lines <- read_utf8(file)
   }
 
   knit_params <- knitr::knit_params(input_lines)
