@@ -10,7 +10,7 @@
 #' @return R Markdown output format to pass to \code{\link{render}}
 powerpoint_presentation <- function(
   toc = FALSE, toc_depth = 2, fig_width = 5, fig_height = 4, fig_caption = TRUE,
-  df_print = 'default', smart = TRUE, keep_md = FALSE, md_extensions = NULL,
+  df_print = 'default', keep_md = FALSE, md_extensions = NULL,
   slide_level = NULL, reference_doc = 'default', pandoc_args = NULL
 ) {
 
@@ -25,9 +25,6 @@ powerpoint_presentation <- function(
   # base pandoc options for all pptx output
   args <- c()
 
-  # smart quotes, etc.
-  if (smart) md_extensions <- c(md_extensions, '+smart')
-
   # table of contents
   args <- c(args, pandoc_toc_args(toc, toc_depth))
 
@@ -71,9 +68,9 @@ powerpoint_presentation <- function(
 
 # copy the reference doc to the intermediate dir when the dir is specified
 reference_intermediates_generator <- function(
-  saved_files_dir, original_input, encoding, intermediates_dir, reference_doc
+  saved_files_dir, original_input, intermediates_dir, reference_doc
 ) {
-  res <- general_intermediates_generator(saved_files_dir,  original_input, encoding, intermediates_dir)
+  res <- general_intermediates_generator(saved_files_dir,  original_input, intermediates_dir)
   if (is.null(reference_doc) || identical(reference_doc, 'default')) return(res)
   if (!is_relative(reference_doc)) return(res)  # an absolute path was provided; no need to copy
   doc  <- normalize_path(reference_doc, mustWork = TRUE)
