@@ -398,17 +398,17 @@ render <- function(input,
                             format = "Rmd")
     intermediates <- c(intermediates, spin_rmd)
     knit_input <- spin_rmd
-    # append default metadata (this will be ignored if there is user
-    # metadata elsewhere in the file)
-    metadata <- paste('\n',
-      '---\n',
-      'title: "', input, '"\n',
-      'author: "', Sys.info()[["user"]], '"\n',
-      'date: "', Sys.Date(), '"\n',
-      '---\n'
-    , sep = "")
-    input_lines <- read_utf8(knit_input)
-    write_utf8(c(input_lines, metadata), knit_input)
+    # append default metadata unless the field exists in YAML
+    meta1 <- yaml_front_matter(knit_input)
+    meta2 <- list(
+      title = input, author = Sys.info()[["user"]],
+      date = as.character(Sys.Date())
+    )
+    for (i in names(meta2)) if (!is.null(meta1[[i]])) meta2[[i]] <- NULL
+    if (length(meta2)) {
+      input_lines <- read_utf8(knit_input)
+      write_utf8(c(input_lines, '\n\n---', yaml::as.yaml(meta2), '---'), knit_input)
+    }
   }
 
   # read the input file
@@ -780,7 +780,7 @@ render <- function(input,
   # the knitr cache is active; clean the figure-* dir instead of the whole
   # files_dir if other subdirs are generated by another format and still needed:
   # https://github.com/rstudio/rmarkdown/issues/1472 and also #1503
-  if (output_format$clean_supporting && !dir_exists(cache_dir)) {
+  intermediates_fig <- if (output_format$clean_supporting && !dir_exists(cache_dir)) {
     # unlink does not support / at the end of file path
     fig_path <- gsub("/$", "", knitr::opts_chunk$get('fig.path'))
 
@@ -788,15 +788,13 @@ render <- function(input,
     # if no figure is generated, clean the whole files_dir (#1664)
     files_dir_fig <- list.files(files_dir, '^figure-.+')
 
-    intermediates <- c(
-      intermediates,
-      if (length(files_dir_fig) < 1 || identical(files_dir_fig, basename(fig_path))) {
-        files_dir
-      } else {
-        fig_path
-      }
-    )
+    if (length(files_dir_fig) < 1 || identical(files_dir_fig, basename(fig_path))) {
+      files_dir
+    } else {
+      fig_path
+    }
   }
+  intermediates <- c(intermediates, intermediates_fig)
 
   file.copy(input, utf8_input, overwrite = TRUE)
 
@@ -912,6 +910,7 @@ render <- function(input,
       convert(texfile, run_citeproc && !need_bibtex)
       # patch the .tex output generated from the default Pandoc LaTeX template
       if (!("--template" %in% output_format$pandoc$args)) patch_tex_output(texfile)
+      fix_horiz_rule(texfile)
       # unless the output file has the extension .tex, we assume it is PDF
       if (!grepl('[.]tex$', output_file)) {
         latexmk(texfile, output_format$pandoc$latex_engine, '--biblatex' %in% output_format$pandoc$args)
@@ -967,6 +966,8 @@ render <- function(input,
       attr(output_file, 'rmd_output_metadata') <- output_meta
     invisible(output_file)
   } else {
+    # make sure the markdown output and fig dir are not cleaned up
+    intermediates <- setdiff(intermediates, c(input, intermediates_fig))
     # did not run pandoc; returns the markdown output with attributes of the
     # knitr meta data and intermediate files
     structure(input, knit_meta = knit_meta, intermediates = intermediates)
