@@ -31,7 +31,7 @@ test_that("an example R Notebook document can be rendered and parsed", {
 
   # try parsing and validating the parse format
   parsed <- parse_html_notebook(file)
-  expect_identical(parsed$rmd, read_utf8(path, encoding = "UTF-8"))
+  expect_identical(parsed$rmd, read_utf8(path))
 })
 
 test_that("a custom output_source can be used on render", {
@@ -109,3 +109,26 @@ test_that("a custom output_source can be used on render", {
   parsed <- parse_html_notebook(output_file)
 
 })
+
+test_that("UFT8 character in html widget does not break notebook annotation", {
+  # from issue in https://github.com/rstudio/rmarkdown/issues/1762
+  skip_on_cran()
+  # simulate html widget code
+  html_dependency_dummy <- function()  {
+    htmltools::htmlDependency(
+      name = "dummy",
+      version = "0.0.0",
+      src = "dummy_file",
+      script = "dummy.js")
+  }
+  utf8_strings <- enc2utf8("éà")
+  output <- htmltools::htmlPreserve(utf8_strings)
+  output <- knitr::asis_output(output, meta = html_dependency_dummy())
+  reg_res <- paste0(
+    "<!-- rnb-htmlwidget-begin .*-->\n",
+    utf8_strings,"\n",
+    "<!-- rnb-htmlwidget-end -->\n"
+  )
+  expect_match(notebook_render_html_widget(output),
+               reg_res)
+})
